# Copyright 2018, 2019 Cumulus Networks, Inc.  All Rights reserved.
# This software is subject to the Cumulus Networks End User License Agreement
# available at the following locations:
# Internet: https://cumulusnetworks.com/downloads/eula/latest/view/
# Cumulus Linux systems: /usr/share/cumulus/EULA.txt

from netq_lib.orm.redisdb.models import ConfigMon
from netq_agent.parsers.common.configMon import ConfigMonRender


class SonicConfigMonRender(ConfigMonRender):

    def __init__(self):
        super(SonicConfigMonRender, self).__init__()

    def get_config_dict(self):
        conf_dict = {
            'config-diff': {
                'config_db': '/etc/sonic/config_db.json',
                'bgpd': '/etc/frr/bgpd.conf',
                'zebra': '/etc/frr/zebra.conf',
                #'lldpd': '/etc/lldpd.d/README.conf', #TODO:
            }
        }
        return conf_dict

    def has_special_handling(self, filename):
        if filename == 'lldpd':
            return True

        return False

    def get_last_modify_time(self, filepath):
        return None     #TODO:

    def build_platform_specific_objs(self, filename, filepath, fullstate, mem_modify_time, current_modify_time):
        if filename == 'lldpd':
            # For LLDP, the conf file is present within the docker instance
            result = self.run_command('docker exec -it lldp cat {}'.format(filepath))
            if result.success and result.op:
                if int(current_modify_time) > mem_modify_time or fullstate:
                    new_config_mon_obj = ConfigMon()
                    new_config_mon_obj.file_name = filename
                    new_config_mon_obj.last_modify_time = current_modify_time
                    new_config_mon_obj.file_content = result.op.decode()

                    return new_config_mon_obj


def process_config_mon(cmd_output, svc_failed=False, **kwargs):
    render = SonicConfigMonRender()
    return render.parse(cmd_output, svc_failed, **kwargs)
