# Copyright 2018, 2019, 2020 Cumulus Networks, Inc.  All Rights reserved.
#
# This software is subject to the Cumulus Networks End User License Agreement
# available at the following locations:
#
# Internet: https://cumulusnetworks.com/downloads/eula/latest/view/
# Cumulus Linux systems: /usr/share/cumulus/EULA.txt


from netq_lib.orm.redisdb.models import OS, ASIC
from netq_lib.common.enums import Platform
from netq_agent.parsers.common.platform import PlatformRender, OK


class SonicPlatformRender(PlatformRender):
    def __init__(self):
        super(SonicPlatformRender, self).__init__()

    def process_os_info(self, logger, os_release):
        os = OS()
        os.name = 'N/A'
        os.version = 'N/A'
        os.version_id = 'N/A'

        try:
            if os_release is not None:
                for line in os_release.splitlines():
                    os.name = Platform.SONIC
                    if line.startswith('kernel_version:'):
                        os.version = line.split(':')[1].strip().strip('\"').strip("\'")
                    if line.startswith('build_version:'):
                        os.version_id = line.split(':')[1].strip().strip('\"').strip("\'")
        except (IndexError, ValueError) as ex:
            logger.error("Failed to process os info: {}".format(ex))
            raise ex

        return os


    def process_asic_info(self, logger, board, show_version, platform_detect):
        asic = ASIC()

        asic.vendor = 'N/A'
        asic.model = 'N/A'
        asic.model_id = 'N/A'
        asic.core_bw = 'N/A'
        asic.ports = 'N/A'

        asic.vendor = 'NVIDIA'

        try:
            if show_version is not None:
                for line in show_version.splitlines():
                    if line.startswith('ASIC'):
                        asic.model = line.split(':')[1].strip(chr(0))
                        board.vendor = line.split(':')[1].strip(chr(0))
                    if line.startswith('Serial Number'):
                        asic.model_id = line.split(':')[1].strip(chr(0))
                    if line.startswith('HwSKU'):
                        board.model = line.split(':')[1].strip(chr(0))

        except (IndexError, ValueError) as ex:
            logger.error("Failed to process platform information: {}".format(ex))
            raise ex

        return asic

    def process_os_license_info(self, cmd_output, svc_status=OK, **kwargs):
        return None, None


def process_platform_info(
        logger,
        random_platform,
        platform,
        os_release,
        decode_syseeprom,
        lscpu,
        meminfo,
        show_version,
        meminfo_dmi,
        lsblk,
        agent_version,
        platform_detect,
        is_full_state,
        app_release_info
):
    render = SonicPlatformRender()
    render.process_platform_info(logger, random_platform, platform,
                                 os_release, decode_syseeprom, lscpu,
                                 meminfo, show_version, meminfo_dmi,
                                 lsblk, agent_version, platform_detect,
                                 is_full_state, app_release_info)
