# Copyright 2018, 2020 Cumulus Networks, Inc.  All Rights reserved.
#
# This software is subject to the Cumulus Networks End User License Agreement
# available at the following locations:
#
# Internet: https://cumulusnetworks.com/downloads/eula/latest/view/
# Cumulus Linux systems: /usr/share/cumulus/EULA.txt


import subprocess
from netq_lib.common.utils import save_fullstate, subprocess_wrapper
from netq_agent.parsers.common.ports import PortsRender


class SonicPortsRender(PortsRender):
    def __init__(self):
        super(SonicPortsRender, self).__init__()

    def ethtool_fetch_port_info(self, port_name):
        ethtool_dict = dict()
        try:
            ethtool_dump = subprocess_wrapper(['/sbin/ethtool', port_name])
            for line in ethtool_dump.splitlines():
                if ':' not in line:
                    continue
                key, value = line.split(':', 1)
                key = key.strip()
                value = value.strip()
                if key in list(ethtool_dict.keys()):
                    ethtool_dict[key] = ethtool_dict[key] + '| ' + value
                else:
                    ethtool_dict[key] = value
        except subprocess.CalledProcessError:
            pass

        return ethtool_dict

    def ethtool_fetch_test_serial_number(self, port_name):
        return None

    def ethtool_fetch_eeprom_optical_info(self, port_name):
        return dict()


def process_ports(cmd_output, svc_failed=False, **kwargs):
    ports_render.parse(cmd_output, svc_failed, **kwargs)


ports_render = SonicPortsRender()